.. _spkg_database_cubic_hecke:

database_cubic_hecke: Ivan Marin's representations of the cubic Hecke algebra
=============================================================================

Description
-----------

Ivan Marin's representations of the cubic Hecke algebra on 4 strands as Python dictionaries

License
-------

GPL

Upstream Contact
----------------

https://pypi.org/project/database-cubic-hecke/



Type
----

optional


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)

Version Information
-------------------

package-version.txt::

    2022.4.4

version_requirements.txt::

    database-cubic-hecke

Equivalent System Packages
--------------------------

(none known)
